[pkg-eucalyptus-commits] [SCM] managing cloud instances for Eucalyptus branch, master, updated. 3.0.0-alpha3-257-g1da8e3a

Garrett Holmstrom gholms at fedoraproject.org
Sun Jun 16 02:31:30 UTC 2013


The following commit has been merged in the master branch:
commit b7b8b5311d9cf0c18d3bf7f51ffa670de883ceb9
Author: Garrett Holmstrom <gholms at fedoraproject.org>
Date:   Wed May 29 16:33:41 2013 -0700

    Support AWS_ACCESS_KEY and AWS_SECRET_KEY in euca-*

diff --git a/euca2ools/commands/euca/__init__.py b/euca2ools/commands/euca/__init__.py
index f32ab67..bd7d7ab 100644
--- a/euca2ools/commands/euca/__init__.py
+++ b/euca2ools/commands/euca/__init__.py
@@ -101,7 +101,11 @@ class EC2CompatibleQuerySigV2Auth(QuerySigV2Auth):
                 self.args['key_id'] = config['EC2_ACCESS_KEY']
             if 'EC2_SECRET_KEY' in config and not self.args.get('secret_key'):
                 self.args['secret_key'] = config['EC2_SECRET_KEY']
-        # Environment (for compatibility with EC2 tools)
+        # Environment (for compatibility with AWS tools)
+        if 'AWS_ACCESS_KEY' in os.environ and not self.args.get('key_id'):
+            self.args['key_id'] = os.getenv('AWS_ACCESS_KEY')
+        if 'AWS_SECRET_KEY' in os.environ and not self.args.get('secret_key'):
+            self.args['secret_key'] = os.getenv('AWS_SECRET_KEY')
         if 'EC2_ACCESS_KEY' in os.environ and not self.args.get('key_id'):
             self.args['key_id'] = os.getenv('EC2_ACCESS_KEY')
         if 'EC2_SECRET_KEY' in os.environ and not self.args.get('secret_key'):

-- 
managing cloud instances for Eucalyptus



More information about the pkg-eucalyptus-commits mailing list